summaryrefslogtreecommitdiff
path: root/lib/make
diff options
context:
space:
mode:
Diffstat (limited to 'lib/make')
-rw-r--r--lib/make/make.config.defn.in2
-rw-r--r--lib/make/make.configuration4
-rw-r--r--lib/make/make.thornlib2
-rwxr-xr-xlib/make/new_thorn.pl16
4 files changed, 12 insertions, 12 deletions
diff --git a/lib/make/make.config.defn.in b/lib/make/make.config.defn.in
index a9e44bf6..3c7b6272 100644
--- a/lib/make/make.config.defn.in
+++ b/lib/make/make.config.defn.in
@@ -11,7 +11,7 @@
# @version $Id$
# @@*/
-# Include stuff defined by optional extra packages
+# Include stuff defined by optional extra arrangements
include $(TOP)/config-data/make.extra.defn
diff --git a/lib/make/make.configuration b/lib/make/make.configuration
index f4e7e892..88458f5b 100644
--- a/lib/make/make.configuration
+++ b/lib/make/make.configuration
@@ -119,8 +119,8 @@ $(CONFIG)/make.thornlist: $(TOP)/ThornList $(foreach lib, $(CCTK_HOME)/src $(THO
$(TOP)/ThornList:
@echo $(DIVIDER)
- @echo Creating compiled ThornList containing all thorns in the packages directory
- $(PERL) -s $(BUILD_ACTIVETHORNS) $(CCTK_HOME)/packages > $@
+ @echo Creating compiled ThornList containing all thorns in the arrangements directory
+ $(PERL) -s $(BUILD_ACTIVETHORNS) $(CCTK_HOME)/arrangements > $@
action="yes"; if [ "x$$EDITOR" = "x" ] ; then EDITOR=vi ; fi; \
while [ "x$$action" = "xyes" -o "x$$action" = "xy" -o "x$$action" = "xYES" -o "x$$action" = "xY" ] ; \
do \
diff --git a/lib/make/make.thornlib b/lib/make/make.thornlib
index 76830b76..80dbf046 100644
--- a/lib/make/make.thornlib
+++ b/lib/make/make.thornlib
@@ -19,7 +19,7 @@ DIVIDER = $(DIVEL)$(DIVEL)$(DIVEL)$(DIVEL)
include $(CONFIG)/make.config.defn
# Add appropriate include lines
-INC_DIRS = $(SYS_INC_DIRS) $(SRCDIR) $(SRCDIR)/include $(CONFIG) $(TOP)/bindings/include $(CCTK_HOME)/src/include $(CCTK_HOME)/packages
+INC_DIRS = $(SYS_INC_DIRS) $(SRCDIR) $(SRCDIR)/include $(CONFIG) $(TOP)/bindings/include $(CCTK_HOME)/src/include $(CCTK_HOME)/arrangements
# Allow subdirectories to inherit these include directories
export INC_DIRS
diff --git a/lib/make/new_thorn.pl b/lib/make/new_thorn.pl
index ffb1d2b6..2a9c90e3 100755
--- a/lib/make/new_thorn.pl
+++ b/lib/make/new_thorn.pl
@@ -9,7 +9,7 @@
# @version $Id$
#@@*/
-$package_dir = "packages";
+$package_dir = "arrangements";
$thorn_name = shift(@ARGV);
@@ -20,10 +20,10 @@ if(!$thorn_name)
if(!$package)
{
- @packages = &GetToolkits($package_dir);
+ @arrangements = &GetToolkits($package_dir);
- print "The following packages are available:\n";
- foreach $package (@packages)
+ print "The following arrangements are available:\n";
+ foreach $package (@arrangements)
{
print "$package\n";
}
@@ -182,7 +182,7 @@ sub prompt {
# @date Wed Feb 3 16:45:22 1999
# @author Tom Goodale
# @desc
# Gets a list of the current packages.
# @enddesc
# @calls
# @calledby
@@ -195,7 +195,7 @@ sub GetToolkits
{
local($package_dir) = @_;
local($start_dir);
- local(@packages);
+ local(@arrangements);
$start_dir = `pwd`;
@@ -215,7 +215,7 @@ sub GetToolkits
# Just pick directories
if( -d $_)
{
- push (@packages, $_);
+ push (@arrangements, $_);
}
}
@@ -223,5 +223,5 @@ sub GetToolkits
chdir $start_dir;
- return @packages;
+ return @arrangements;
}
@@ -182,7 +182,7 @@ sub prompt {
# @author Tom Goodale
# @desc
-# Gets a list of the current packages.
+# Gets a list of the current arrangements.
# @enddesc
# @calls